searchData={"items":[{"type":"module","title":"JSONPointer","doc":"An implementation of [JSON Pointer (RFC 6901)](http://tools.ietf.org/html/draft-ietf-appsawg-json-pointer-08) for Elixir.","ref":"JSONPointer.html"},{"type":"function","title":"JSONPointer.add/4","doc":"Adds a value using the given pointer.\n\nFollows the JSON patch behaviour specified in RFC6902.","ref":"JSONPointer.html#add/4"},{"type":"function","title":"Examples - JSONPointer.add/4","doc":"iex> JSONPointer.add( %{ \"fridge\" => [ \"milk\", \"cheese\" ] }, \"/fridge/1\", \"salad\")\n    {:ok, %{ \"fridge\" => [ \"milk\", \"salad\", \"cheese\" ]}, [ \"milk\", \"cheese\" ] }\n\n    iex> JSONPointer.add( %{ \"a\" => %{\"b\" => %{}}}, \"/a/b/c\", [\"foo\", \"bar\"] )\n    {:ok, %{\"a\" => %{\"b\" => %{\"c\" => [\"foo\", \"bar\"]}}}, nil}","ref":"JSONPointer.html#add/4-examples"},{"type":"function","title":"JSONPointer.add!/4","doc":"Adds a value using the given pointer, raises an error on exception.","ref":"JSONPointer.html#add!/4"},{"type":"function","title":"Examples - JSONPointer.add!/4","doc":"iex> JSONPointer.add!( %{ \"a\" => %{ \"foo\"  => 1 } }, \"/a/b\", true )\n    %{\"a\" => %{\"foo\" => 1, \"b\" => true}}","ref":"JSONPointer.html#add!/4-examples"},{"type":"function","title":"JSONPointer.dehydrate/1","doc":"Extracts a list of JSON pointer paths from the given object.","ref":"JSONPointer.html#dehydrate/1"},{"type":"function","title":"Examples - JSONPointer.dehydrate/1","doc":"iex> JSONPointer.dehydrate( %{\"a\"=>%{\"b\"=>[\"c\",\"d\"]}} )\n    {:ok, [{\"/a/b/0\", \"c\"}, {\"/a/b/1\", \"d\"}] }\n\n    iex> JSONPointer.dehydrate( %{\"a\"=>[10, %{\"b\"=>12.5}], \"c\"=>99} )\n    {:ok, [{\"/a/0\", 10}, {\"/a/1/b\", 12.5}, {\"/c\", 99}] }","ref":"JSONPointer.html#dehydrate/1-examples"},{"type":"function","title":"JSONPointer.dehydrate!/1","doc":"Extracts a list of JSON pointer paths from the given object, raises\nan error on exception.","ref":"JSONPointer.html#dehydrate!/1"},{"type":"function","title":"Examples - JSONPointer.dehydrate!/1","doc":"iex> JSONPointer.dehydrate!( %{\"a\"=>%{\"b\"=>[\"c\",\"d\"]}} )\n    [{\"/a/b/0\", \"c\"}, {\"/a/b/1\", \"d\"}]\n\n    iex> JSONPointer.dehydrate!( %{\"a\"=>[10, %{\"b\"=>12.5}], \"c\"=>99} )\n    [{\"/a/0\", 10}, {\"/a/1/b\", 12.5}, {\"/c\", 99}]","ref":"JSONPointer.html#dehydrate!/1-examples"},{"type":"function","title":"JSONPointer.get/3","doc":"Retrieves the value indicated by the pointer from the object.","ref":"JSONPointer.html#get/3"},{"type":"function","title":"Examples - JSONPointer.get/3","doc":"iex> JSONPointer.get( %{ \"fridge\" => %{ \"door\" => \"milk\" } }, \"/fridge/door\" )\n    {:ok, \"milk\"}\n\n    iex> JSONPointer.get( %{ \"contents\" => [ \"milk\", \"butter\", \"eggs\" ]}, \"/contents/2\" )\n    {:ok, \"eggs\"}\n\n    iex> JSONPointer.get( %{ \"milk\" => true, \"butter\" => false}, \"/cornflakes\" )\n    {:error, \"key not found: /cornflakes\"}\n\n    iex> JSONPointer.get( %{ \"contents\" => [ \"milk\", \"butter\", \"eggs\" ]}, \"/contents/4\" )\n    {:error, \"index out of bounds: 4\"}\n\n    iex> JSONPointer.get( %{ \"fridge\" => %{ \"cake\" => true }, \"stove\" => nil}, \"/stove/cake\" )\n    {:error, \"key not found: /cake\"}","ref":"JSONPointer.html#get/3-examples"},{"type":"function","title":"JSONPointer.get!/3","doc":"Retrieves the value indicated by the pointer from the object, raises\nan error on exception.","ref":"JSONPointer.html#get!/3"},{"type":"function","title":"Examples - JSONPointer.get!/3","doc":"iex> JSONPointer.get!( %{ \"fridge\" => %{ \"milk\" => true}}, \"/fridge/milk\" )\n    true\n    iex> JSONPointer.get!( %{}, \"/fridge/milk\" )\n    ** (ArgumentError) key not found: /fridge\n\n    iex> JSONPointer.get!( %{ \"fridge\" => %{ \"cake\" => true }, \"stove\" => nil}, \"/stove/cake\" )\n    ** (ArgumentError) key not found: /cake","ref":"JSONPointer.html#get!/3-examples"},{"type":"function","title":"JSONPointer.has?/3","doc":"Returns true if the given JSON Pointer resolves to a value.","ref":"JSONPointer.html#has?/3"},{"type":"function","title":"Examples - JSONPointer.has?/3","doc":"iex> JSONPointer.has?( %{ \"milk\" => true, \"butter\" => false}, \"/butter\" )\n    true\n\n    iex> JSONPointer.has?( %{ \"milk\" => true, \"butter\" => false}, \"/cornflakes\" )\n    false\n\n    iex> JSONPointer.has?( %{ \"fridge\" => %{ \"cake\" => true }, \"stove\" => nil}, \"/stove/cake\" )\n    false","ref":"JSONPointer.html#has?/3-examples"},{"type":"function","title":"JSONPointer.hydrate/1","doc":"Returns the given list of paths applied to a container.","ref":"JSONPointer.html#hydrate/1"},{"type":"function","title":"Examples - JSONPointer.hydrate/1","doc":"iex> JSONPointer.hydrate( [ {\"/a/1/b\", \"single\"} ] )\n    {:ok, %{\"a\" => %{\"1\" => %{\"b\" => \"single\"}}}}","ref":"JSONPointer.html#hydrate/1-examples"},{"type":"function","title":"JSONPointer.hydrate/2","doc":"Applies the given list of paths to the given container.","ref":"JSONPointer.html#hydrate/2"},{"type":"function","title":"Examples - JSONPointer.hydrate/2","doc":"iex> JSONPointer.hydrate( %{}, [ {\"/a/b/1\", \"find\"} ] )\n    {:ok, %{\"a\"=>%{\"b\"=>[nil,\"find\"]} } }","ref":"JSONPointer.html#hydrate/2-examples"},{"type":"function","title":"JSONPointer.hydrate!/1","doc":"Returns the given list of paths applied to a container, raises an exception\non error.","ref":"JSONPointer.html#hydrate!/1"},{"type":"function","title":"Examples - JSONPointer.hydrate!/1","doc":"iex> JSONPointer.hydrate!( [ {\"/a/b/1\", \"find\"} ] )\n    %{\"a\"=>%{\"b\"=>[nil,\"find\"]} }","ref":"JSONPointer.html#hydrate!/1-examples"},{"type":"function","title":"JSONPointer.hydrate!/2","doc":"Applies the given list of paths to the given container, raises an exception\non error.","ref":"JSONPointer.html#hydrate!/2"},{"type":"function","title":"Examples - JSONPointer.hydrate!/2","doc":"iex> JSONPointer.hydrate!( %{}, [ {\"/a/b/1\", \"find\"} ] )\n    %{\"a\"=>%{\"b\"=>[nil,\"find\"]} }","ref":"JSONPointer.html#hydrate!/2-examples"},{"type":"function","title":"JSONPointer.merge/2","doc":"Merges the incoming dst object into src.","ref":"JSONPointer.html#merge/2"},{"type":"function","title":"Examples - JSONPointer.merge/2","doc":"iex> JSONPointer.merge( %{\"a\"=>1}, %{\"b\"=>2} )\n    {:ok, %{\"a\"=>1,\"b\"=>2} }\n\n    iex> JSONPointer.merge( [\"foo\", \"bar\"], [\"baz\"] )\n    {:ok, [\"baz\", \"bar\"]}","ref":"JSONPointer.html#merge/2-examples"},{"type":"function","title":"JSONPointer.merge!/2","doc":"Merges the incoming dst object into src, raises an error on exception.","ref":"JSONPointer.html#merge!/2"},{"type":"function","title":"Examples - JSONPointer.merge!/2","doc":"iex> JSONPointer.merge!( %{\"a\"=>1}, %{\"b\"=>2} )\n    %{\"a\"=>1,\"b\"=>2}\n\n    iex> JSONPointer.merge!( [\"foo\", \"bar\"], [\"baz\"] )\n    [\"baz\", \"bar\"]","ref":"JSONPointer.html#merge!/2-examples"},{"type":"function","title":"JSONPointer.remove/3","doc":"Removes an attribute of object referenced by pointer.","ref":"JSONPointer.html#remove/3"},{"type":"function","title":"Examples - JSONPointer.remove/3","doc":"iex> JSONPointer.remove( %{\"fridge\" => %{ \"milk\" => true, \"butter\" => true}}, \"/fridge/butter\" )\n    {:ok, %{\"fridge\" => %{\"milk\"=>true}}, true }\n\n    iex> JSONPointer.remove( %{\"fridge\" => %{ \"milk\" => true, \"butter\" => true}}, \"/fridge/sandwich\" )\n    {:error, \"key not found: /sandwich\", %{ \"butter\" => true, \"milk\" => true}}\n\n    iex> JSONPointer.remove( %{ \"fridge\" => %{ \"cake\" => true }, \"stove\" => nil}, \"/stove/cake\" )\n    {:error, \"key not found: /cake\", nil}","ref":"JSONPointer.html#remove/3-examples"},{"type":"function","title":"JSONPointer.set/4","doc":"Sets a new value on object at the location described by pointer.","ref":"JSONPointer.html#set/4"},{"type":"function","title":"Examples - JSONPointer.set/4","doc":"iex> JSONPointer.set( %{}, \"/example/msg\", \"hello\")\n    {:ok, %{ \"example\" => %{ \"msg\" => \"hello\" }}, nil }\n\n    iex> JSONPointer.set( %{}, \"/fridge/contents/1\", \"milk\" )\n    {:ok, %{\"fridge\" => %{\"contents\" => [nil, \"milk\"]}}, nil }\n\n    iex> JSONPointer.set( %{\"milk\"=>\"full\"}, \"/milk\", \"empty\")\n    {:ok, %{\"milk\" => \"empty\"}, \"full\"}","ref":"JSONPointer.html#set/4-examples"},{"type":"function","title":"JSONPointer.set!/4","doc":"Sets a new value on object at the location described by pointer, raises\nan error on exception.","ref":"JSONPointer.html#set!/4"},{"type":"function","title":"Examples - JSONPointer.set!/4","doc":"iex> JSONPointer.set!( %{}, \"/example/msg\", \"hello\")\n    %{ \"example\" => %{ \"msg\" => \"hello\" }}\n\n    iex> JSONPointer.set!( %{}, \"/fridge/contents/1\", \"milk\" )\n    %{\"fridge\" => %{\"contents\" => [nil, \"milk\"]}}\n\n    iex> JSONPointer.set!( %{\"milk\"=>\"full\"}, \"/milk\", \"empty\")\n    %{\"milk\" => \"empty\"}","ref":"JSONPointer.html#set!/4-examples"},{"type":"function","title":"JSONPointer.test/4","doc":"Tests whether a JSON Pointer equals the given value.","ref":"JSONPointer.html#test/4"},{"type":"function","title":"Examples - JSONPointer.test/4","doc":"iex> JSONPointer.test( %{ \"milk\" => \"skimmed\", \"butter\" => false}, \"/milk\", \"skimmed\" )\n    {:ok, %{ \"milk\" => \"skimmed\", \"butter\" => false} }\n\n    iex> JSONPointer.test( %{ \"fridge\" => %{ \"cake\" => true }, \"stove\" => nil}, \"/stove/cake\", \"true\" )\n    {:error, \"key not found: /cake\"}","ref":"JSONPointer.html#test/4-examples"},{"type":"function","title":"JSONPointer.test!/4","doc":"Tests whether a JSON Pointer equals the given value, raises an error if they don't.","ref":"JSONPointer.html#test!/4"},{"type":"function","title":"Examples - JSONPointer.test!/4","doc":"iex> JSONPointer.test!( %{ \"milk\" => \"skimmed\", \"butter\" => false}, \"/butter\", \"unsalted\" )\n    ** (ArgumentError) not equal\n\n    iex> JSONPointer.test!( %{ \"fridge\" => %{ \"cake\" => true }, \"stove\" => nil}, \"/stove/cake\", \"true\" )\n    ** (ArgumentError) key not found: /cake","ref":"JSONPointer.html#test!/4-examples"},{"type":"function","title":"JSONPointer.transform/2","doc":"Applies a mapping of source paths to destination paths in the result.\n\nThe mapping can optionally include a function which transforms the source\nvalue before it is applied to the result.","ref":"JSONPointer.html#transform/2"},{"type":"function","title":"Examples - JSONPointer.transform/2","doc":"iex> JSONPointer.transform( %{ \"a\"=>4, \"b\"=>%{ \"c\" => true }}, [ {\"/b/c\", \"/valid\"}, {\"/a\",\"/count\", fn val -> val*2 end} ] )\n    {:ok, %{\"count\" => 8, \"valid\" => true}}","ref":"JSONPointer.html#transform/2-examples"},{"type":"function","title":"JSONPointer.transform!/2","doc":"Applies a mapping of source paths to destination paths in the result, raises an\nerror on exception.\n\nThe mapping can optionally include a function which transforms the source\nvalue before it is applied to the result.","ref":"JSONPointer.html#transform!/2"},{"type":"function","title":"Examples - JSONPointer.transform!/2","doc":"iex> JSONPointer.transform!( %{ \"a\"=>5, \"b\"=>%{ \"is_valid\" => true }}, [ {\"/b/is_valid\", \"/valid\"}, {\"/a\",\"/count\", fn val -> val*2 end} ] )\n    %{\"count\" => 10, \"valid\" => true}","ref":"JSONPointer.html#transform!/2-examples"},{"type":"type","title":"JSONPointer.container/0","doc":"the item on which the operations are applied","ref":"JSONPointer.html#t:container/0"},{"type":"type","title":"JSONPointer.error_message/0","doc":"return error tuple","ref":"JSONPointer.html#t:error_message/0"},{"type":"type","title":"JSONPointer.existing/0","doc":"data that was affected by an operation","ref":"JSONPointer.html#t:existing/0"},{"type":"type","title":"JSONPointer.options/0","doc":"options that may be passed to functions to control outcomes","ref":"JSONPointer.html#t:options/0"},{"type":"type","title":"JSONPointer.pointer/0","doc":"the JSON Pointer value","ref":"JSONPointer.html#t:pointer/0"},{"type":"type","title":"JSONPointer.pointer_list/0","doc":"a tuple of JSON Pointer and value","ref":"JSONPointer.html#t:pointer_list/0"},{"type":"type","title":"JSONPointer.removed/0","doc":"data that was removed by an operation","ref":"JSONPointer.html#t:removed/0"},{"type":"type","title":"JSONPointer.t/0","doc":"return type","ref":"JSONPointer.html#t:t/0"},{"type":"type","title":"JSONPointer.transform_mapping/0","doc":"argument passed to transform/2 mapping a pointer using a function or\nanother pointer","ref":"JSONPointer.html#t:transform_mapping/0"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\nWritten with guidance from [Keep a CHANGELOG](http://keepachangelog.com/).\nThis project adheres to [Semantic Versioning](http://semver.org/).\n\n## [Unreleased]","ref":"changelog.html"},{"type":"extras","title":"v3.1.0 (2024-09-11) - Changelog","doc":"","ref":"changelog.html#v3-1-0-2024-09-11"},{"type":"extras","title":"Changed - Changelog","doc":"- updated package dependencies\n- error handling for get on invalid containers\n- error message format changed to be more consistent","ref":"changelog.html#changed"},{"type":"extras","title":"v3.0.1 (2019-07-31) - Changelog","doc":"","ref":"changelog.html#v3-0-1-2019-07-31"},{"type":"extras","title":"Fixed - Changelog","doc":"- crash when retrieving a path which contains a null value","ref":"changelog.html#fixed"},{"type":"extras","title":"v3.0.0 (2019-02-27) - Changelog","doc":"","ref":"changelog.html#v3-0-0-2019-02-27"},{"type":"extras","title":"Added - Changelog","doc":"- add/add! - adds values indicated by pointers\n- options can be passed to operations. only option so far is :strict which affects set/add behaviour\n- added JSONPointer.test - checks whether the given pointer has the given value","ref":"changelog.html#added"},{"type":"extras","title":"Changed - Changelog","doc":"- has changed to has? as it returns a single boolean\n- stricter parsing of integer indexes\n- increased terseness of error messages\n- remove now actually reduces the list size, rather than replace with nil","ref":"changelog.html#changed"},{"type":"extras","title":"Fixed - Changelog","doc":"- corrected parsing of /~01","ref":"changelog.html#fixed"},{"type":"extras","title":"v2.5.0 (2019-02-22) - Changelog","doc":"","ref":"changelog.html#v2-5-0-2019-02-22"},{"type":"extras","title":"Added - Changelog","doc":"- support for special array rules - /01 is not evaluated to an integer\n- the /- pointer when used with set either appends the value to the end of a list, or\ncreates a new list with the value","ref":"changelog.html#added"},{"type":"extras","title":"v2.4.0 (2019-04-01) - Changelog","doc":"","ref":"changelog.html#v2-4-0-2019-04-01"},{"type":"extras","title":"Fixed - Changelog","doc":"- pointers are no longer uri decoded, so the rfc example of \"/c%d\" now works correctly","ref":"changelog.html#fixed"},{"type":"extras","title":"v2.3.0 (2018-05-09) - Changelog","doc":"","ref":"changelog.html#v2-3-0-2018-05-09"},{"type":"extras","title":"Changed - Changelog","doc":"- JSONPointer.apply changed to JSONPointer.transform","ref":"changelog.html#changed"},{"type":"extras","title":"v2.2.0 (2018-04-12) - Changelog","doc":"","ref":"changelog.html#v2-2-0-2018-04-12"},{"type":"extras","title":"Added - Changelog","doc":"- hydrate and dehydrate functions added\n- apply added - a utility to transform a source container","ref":"changelog.html#added"},{"type":"extras","title":"Removed - Changelog","doc":"- extract - renamed to dehydrate","ref":"changelog.html#removed"},{"type":"extras","title":"v2.1.0 (2018-04-12) - Changelog","doc":"","ref":"changelog.html#v2-1-0-2018-04-12"},{"type":"extras","title":"Added - Changelog","doc":"- set!, extract!, merge!","ref":"changelog.html#added"},{"type":"extras","title":"v2.0.0 (2018-01-19) - Changelog","doc":"","ref":"changelog.html#v2-0-0-2018-01-19"},{"type":"extras","title":"Changed - Changelog","doc":"- passing a string to get/set will raise an argument error\n- new elixir formatter applied to code\n- code refactored to use defguard - which means this package is > 1.6 only","ref":"changelog.html#changed"},{"type":"extras","title":"v1.3.0 (2017-12-21) - Changelog","doc":"","ref":"changelog.html#v1-3-0-2017-12-21"},{"type":"extras","title":"Fixed - Changelog","doc":"- deprecation warning for String.ltrim\n- Unsafe variable warnings","ref":"changelog.html#fixed"},{"type":"extras","title":"v1.2.0 (2016-04-11) - Changelog","doc":"","ref":"changelog.html#v1-2-0-2016-04-11"},{"type":"extras","title":"Added - Changelog","doc":"- parse will take a list of strings\n- JSONPointer.extract returns a list of paths that make up an object\n- JSONPointer.merge combines dst into src","ref":"changelog.html#added"},{"type":"extras","title":"v1.1.0 (2016-03-04) - Changelog","doc":"","ref":"changelog.html#v1-1-0-2016-03-04"},{"type":"extras","title":"Added - Changelog","doc":"- pointers can be passed as lists as well as strings","ref":"changelog.html#added"},{"type":"extras","title":"v1.0.0 (2016-03-03) - Changelog","doc":"* Initial Release","ref":"changelog.html#v1-0-0-2016-03-03"},{"type":"extras","title":"License","doc":"# The MIT License (MIT)\n\nCopyright (c) 2024 Alexander Veenendaal\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"},{"type":"extras","title":"Overview","doc":"# ODGN JSONPointer\n\n[![Build Status](https://travis-ci.org/odogono/elixir-jsonpointer.svg?branch=master)](https://travis-ci.org/odogono/elixir-jsonpointer)\n[![Hex.pm](https://img.shields.io/hexpm/v/odgn_json_pointer.svg?style=flat-square)](https://hex.pm/packages/odgn_json_pointer)\n[![Module Version](https://img.shields.io/hexpm/v/odgn_json_pointer.svg)](https://hex.pm/packages/odgn_json_pointer)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/odgn_json_pointer/)\n[![Total Download](https://img.shields.io/hexpm/dt/odgn_json_pointer.svg)](https://hex.pm/packages/odgn_json_pointer)\n[![License](https://img.shields.io/hexpm/l/odgn_json_pointer.svg)](https://github.com/odogono/elixir-jsonpointer/blob/master/LICENSE.md)\n[![Last Updated](https://img.shields.io/github/last-commit/odogono/elixir-jsonpointer.svg)](https://github.com/odogono/elixir-jsonpointer/commits/master)\n\nAn implementation of [JSON Pointer (RFC 6901)](http://tools.ietf.org/html/draft-ietf-appsawg-json-pointer-08) for Elixir.","ref":"readme.html"},{"type":"extras","title":"Installation - Overview","doc":"Add a dependency to your project `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:odgn_json_pointer, \"~> 3.1.0\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Basic Usage - Overview","doc":"```elixir\niex> JSONPointer.get( %{ \"fridge\" => %{ \"door\" => \"milk\" } }, \"/fridge/door\" )\n{:ok, \"milk\"}\n\niex> JSONPointer.set( %{}, \"/example/msg\", \"hello\")\n{:ok, %{ \"example\" => %{ \"msg\" => \"hello\" }}, nil }\n\niex> JSONPointer.add( %{ \"fridge\" => [ \"milk\", \"cheese\" ]}, \"/fridge/1\", \"salad\")\n{:ok, %{ \"fridge\" => [ \"milk\", \"salad\", \"cheese\" ]}, [ \"milk\", \"cheese\" ] }\n\niex> JSONPointer.has?( %{ \"milk\" => true, \"butter\" => false}, \"/butter\" )\ntrue\n\niex> JSONPointer.test( %{ \"milk\" => \"skimmed\", \"butter\" => false}, \"/milk\", \"skimmed\" )\n{:ok, %{ \"milk\" => \"skimmed\", \"butter\" => false} }\n\niex> JSONPointer.remove( %{\"fridge\" => %{ \"milk\" => true, \"butter\" => true}}, \"/fridge/butter\" )\n{:ok, %{\"fridge\" => %{\"milk\"=>true}}, true }\n\niex> JSONPointer.dehydrate( %{\"a\"=>%{\"b\"=>[\"c\",\"d\"]}} )\n{:ok, [{\"/a/b/0\", \"c\"}, {\"/a/b/1\", \"d\"}] }\n\niex> iex> JSONPointer.hydrate( [ {\"/a/1/b\", \"single\"} ] )\n{:ok, %{\"a\" => %{\"1\" => %{\"b\" => \"single\"}}}}\n\niex> JSONPointer.merge( %{\"a\"=>1}, %{\"b\"=>2} )\n{:ok, %{\"a\"=>1,\"b\"=>2} }\n\niex> JSONPointer.transform( %{ \"a\"=>4, \"b\"=>%{ \"c\" => true }}, [ {\"/b/c\", \"/valid\"}, {\"/a\",\"/count\", fn val -> val*2 end} ] )\n{:ok, %{\"count\" => 8, \"valid\" => true}}\n```\n\nFull documentation can be found at https://hexdocs.pm/odgn_json_pointer.","ref":"readme.html#basic-usage"},{"type":"extras","title":"Acknowledgement - Overview","doc":"Inspiration from https://github.com/manuelstofer/json-pointer\n\nMade without peeking (much) at the source of https://github.com/xavier/json_pointer\n\nMade in Exeter, UK.","ref":"readme.html#acknowledgement"},{"type":"extras","title":"Copyright and License - Overview","doc":"Copyright (c) 2024 Alexander Veenendaal\n\nThis work is free. You can redistribute it and/or modify it under the\nterms of the MIT License. See the [LICENSE.md](./LICENSE.md) file for more details.","ref":"readme.html#copyright-and-license"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}